import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';

import '../flulm_auth.dart';

StreamController<LMAuthResponse> _responseAuthController =
    new StreamController.broadcast();

/// Response from auth
Stream<LMAuthResponse> get responseFromAuth => _responseAuthController.stream;

MethodChannel _channel = const MethodChannel('com.awesome/flulm_auth')
  ..setMethodCallHandler(_handler);

Future<dynamic> _handler(MethodCall methodCall) {
  if ("onAuthResponse" == methodCall.method) {
    _responseAuthController.add(
      LMAuthResponse.fromMap(methodCall.arguments),
    );
  }
  return Future.value(true);
}

Future<void> sendAuth(
    {String openId, @required String scope, String state}) async {
  assert(scope != null && scope.trim().isNotEmpty);
  return await _channel.invokeMethod("sendAuth", {"scope": scope});
}

Future<bool> isLemaPayInstalled() =>
    _channel.invokeMethod("isLemaPayInstalled").then((install) {
      return install;
    });

Future<int> isLemaPaySupportAPI() =>
    _channel.invokeMethod("isLemaPaySupportAPI").then((version) {
      return version;
    });

///[appId] is not necessary.
///if [doOnIOS] is true ,fluwx will register WXApi on iOS.
///if [doOnAndroid] is true, fluwx will register WXApi on Android.
Future register(
    {@required String appId,
    bool doOnIOS: true,
    doOnAndroid: true,
    enableMTA: false}) async {
  return await _channel.invokeMethod("registerApp", {
    "appId": appId,
    "iOS": doOnIOS,
    "android": doOnAndroid,
    "enableMTA": enableMTA
  });
}
